pub struct EventError(pub Box<ErrorContext>);Expand description
Event validation or lifecycle error returned during emit paths.
Tuple Fields
0: Box<ErrorContext>Trait Implementations
Sourceimpl Debug for EventError
impl Debug for EventError
Sourceimpl<'de> Deserialize<'de> for EventError
impl<'de> Deserialize<'de> for EventError
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<EventError, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<EventError, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DiagnosticInfo for EventError
impl DiagnosticInfo for EventError
Sourcefn diagnostic(&self) -> &Diagnostic
fn diagnostic(&self) -> &Diagnostic
Returns the structured diagnostic attached to this error surface.
Sourceimpl Display for EventError
impl Display for EventError
Sourceimpl Error for EventError
impl Error for EventError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for EventError
impl PartialEq for EventError
Sourceimpl Serialize for EventError
impl Serialize for EventError
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for EventError