pub struct ProcessIdentity {
pub hostname: Option<String>,
pub pid: Option<u32>,
}Expand description
Caller-resolved process identity attached to observations and log events.
Fields
hostname: Option<String>Optional hostname attached to the event or observation.
pid: Option<u32>Optional process identifier attached to the event or observation.